@@ -1,23 +1,26 @@
 /* ============================================================
- * File   : interface.cpp
- * Authors: KIPI team developers (see AUTHORS files for details)
- *	    
- * Date   : 2004-02
- * Description :
  *
- * Copyright 2004 by the KIPI team
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-02-01
+ * Description : interface for host application.
+ *
+ * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2005 by Renchi Raju <renchi.raju at kdemail.net>
+ * Copyright (C) 2004-2005 by Jesper K. Pedersen <blackie at kde.org>
+ * Copyright (C) 2004-2005 by Aurelien Gateau <aurelien dot gateau at free.fr>
  *
  * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU Library General
+ * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
- *
+ * GNU General Public License for more details.
+ * 
  * ============================================================ */
 
 /** @file interface.cpp */
@@ -28,9 +31,11 @@
 #include <kimageio.h>
 
 // Local includes.
- 
+
+#include "version.h"
 #include "pluginloader.h"
 #include "interface.h"
+#include "interface.moc"
 
 /*!
   @enum KIPI::Features
@@ -104,6 +109,12 @@ KIPI::Interface::~Interface()
 {
 }
 
+/** Returns a string version of libkipi release */
+QString KIPI::Interface::version()
+{
+  return QString(kipi_version);
+}
+
 /**
    Tells the host app that the following images has changed on disk
 */
@@ -140,6 +151,8 @@ bool KIPI::Interface::hasFeature( const QString& feature )
         return hasFeature( KIPI::AlbumsHaveCreationDate );
     else if ( feature == "AlbumsUseFirstImagePreview" )
         return hasFeature( KIPI::AlbumsUseFirstImagePreview );
+    else if ( feature == "HostSupportsTags" )
+        return hasFeature( KIPI::HostSupportsTags );
     else {
         kdWarning( 51000 ) << "Unknown feature asked for in KIPI::Interface::hasFeature: " << feature << endl;
         return false;
@@ -155,7 +168,7 @@ bool KIPI::Interface::addImage( const KURL&, QString& /*err*/ )
 {
     kdWarning(51000) << "Interface::addImage should only be invoked if the host application supports the KIPI::Features\n"
             "AcceptNewImages - if the host application do support that, then this function should\n"
-            "have been overriden in the host application.\n";
+            "have been overridden in the host application.\n" << endl;
     return false;
 }
 
@@ -205,7 +218,7 @@ int KIPI::Interface::features() const
 }
 
 /**
-   Return a list of images file extention will be used in the plugins for 
+   Return a list of images file extension will be used in the plugins for 
    to sort the files list before a treatment. The default implementation return,
    the supported images formats by KDE.
 */
@@ -215,5 +228,3 @@ QString KIPI::Interface::fileExtensions()
     QString imagesFileFilter = KDEImagetypes.join(" ");
     return ( imagesFileFilter.lower() + " " + imagesFileFilter.upper() );
 }
-
-#include "interface.moc"
